/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.app.builder.rest.internal.graphql.mutation.v1_0;

import com.liferay.app.builder.rest.dto.v1_0.App;
import com.liferay.app.builder.rest.dto.v1_0.AppModelPermission;
import com.liferay.app.builder.rest.resource.v1_0.AppModelPermissionResource;
import com.liferay.app.builder.rest.resource.v1_0.AppResource;
import com.liferay.petra.function.UnsafeConsumer;
import com.liferay.petra.function.UnsafeFunction;
import com.liferay.portal.vulcan.accept.language.AcceptLanguage;
import com.liferay.portal.vulcan.graphql.annotation.GraphQLField;
import com.liferay.portal.vulcan.graphql.annotation.GraphQLName;

import javax.annotation.Generated;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import javax.ws.rs.core.Response;
import javax.ws.rs.core.UriInfo;

import org.osgi.service.component.ComponentServiceObjects;

/**
 * @author Gabriel Albuquerque
 * @generated
 */
@Generated("")
public class Mutation {

	public static void setAppResourceComponentServiceObjects(
		ComponentServiceObjects<AppResource>
			appResourceComponentServiceObjects) {

		_appResourceComponentServiceObjects =
			appResourceComponentServiceObjects;
	}

	public static void setAppModelPermissionResourceComponentServiceObjects(
		ComponentServiceObjects<AppModelPermissionResource>
			appModelPermissionResourceComponentServiceObjects) {

		_appModelPermissionResourceComponentServiceObjects =
			appModelPermissionResourceComponentServiceObjects;
	}

	@GraphQLField
	public boolean deleteApp(@GraphQLName("appId") Long appId)
		throws Exception {

		_applyVoidComponentServiceObjects(
			_appResourceComponentServiceObjects, this::_populateResourceContext,
			appResource -> appResource.deleteApp(appId));

		return true;
	}

	@GraphQLField
	public App updateApp(
			@GraphQLName("appId") Long appId, @GraphQLName("app") App app)
		throws Exception {

		return _applyComponentServiceObjects(
			_appResourceComponentServiceObjects, this::_populateResourceContext,
			appResource -> appResource.putApp(appId, app));
	}

	@GraphQLField
	public Response updateAppDeployment(
			@GraphQLName("appId") Long appId,
			@GraphQLName("deploymentAction")
				com.liferay.app.builder.rest.constant.v1_0.DeploymentAction
					deploymentAction)
		throws Exception {

		return _applyComponentServiceObjects(
			_appResourceComponentServiceObjects, this::_populateResourceContext,
			appResource -> appResource.putAppDeployment(
				appId, deploymentAction));
	}

	@GraphQLField
	public App createDataDefinitionApp(
			@GraphQLName("dataDefinitionId") Long dataDefinitionId,
			@GraphQLName("app") App app)
		throws Exception {

		return _applyComponentServiceObjects(
			_appResourceComponentServiceObjects, this::_populateResourceContext,
			appResource -> appResource.postDataDefinitionApp(
				dataDefinitionId, app));
	}

	@GraphQLField
	public boolean updateAppModelPermission(
			@GraphQLName("appModelPermissions") AppModelPermission[]
				appModelPermissions)
		throws Exception {

		_applyVoidComponentServiceObjects(
			_appModelPermissionResourceComponentServiceObjects,
			this::_populateResourceContext,
			appModelPermissionResource ->
				appModelPermissionResource.putAppModelPermission(
					appModelPermissions));

		return true;
	}

	private <T, R, E1 extends Throwable, E2 extends Throwable> R
			_applyComponentServiceObjects(
				ComponentServiceObjects<T> componentServiceObjects,
				UnsafeConsumer<T, E1> unsafeConsumer,
				UnsafeFunction<T, R, E2> unsafeFunction)
		throws E1, E2 {

		T resource = componentServiceObjects.getService();

		try {
			unsafeConsumer.accept(resource);

			return unsafeFunction.apply(resource);
		}
		finally {
			componentServiceObjects.ungetService(resource);
		}
	}

	private <T, E1 extends Throwable, E2 extends Throwable> void
			_applyVoidComponentServiceObjects(
				ComponentServiceObjects<T> componentServiceObjects,
				UnsafeConsumer<T, E1> unsafeConsumer,
				UnsafeConsumer<T, E2> unsafeFunction)
		throws E1, E2 {

		T resource = componentServiceObjects.getService();

		try {
			unsafeConsumer.accept(resource);

			unsafeFunction.accept(resource);
		}
		finally {
			componentServiceObjects.ungetService(resource);
		}
	}

	private void _populateResourceContext(AppResource appResource)
		throws Exception {

		appResource.setContextAcceptLanguage(_acceptLanguage);
		appResource.setContextCompany(_company);
		appResource.setContextHttpServletRequest(_httpServletRequest);
		appResource.setContextHttpServletResponse(_httpServletResponse);
		appResource.setContextUriInfo(_uriInfo);
		appResource.setContextUser(_user);
	}

	private void _populateResourceContext(
			AppModelPermissionResource appModelPermissionResource)
		throws Exception {

		appModelPermissionResource.setContextAcceptLanguage(_acceptLanguage);
		appModelPermissionResource.setContextCompany(_company);
		appModelPermissionResource.setContextHttpServletRequest(
			_httpServletRequest);
		appModelPermissionResource.setContextHttpServletResponse(
			_httpServletResponse);
		appModelPermissionResource.setContextUriInfo(_uriInfo);
		appModelPermissionResource.setContextUser(_user);
	}

	private static ComponentServiceObjects<AppResource>
		_appResourceComponentServiceObjects;
	private static ComponentServiceObjects<AppModelPermissionResource>
		_appModelPermissionResourceComponentServiceObjects;

	private AcceptLanguage _acceptLanguage;
	private com.liferay.portal.kernel.model.Company _company;
	private com.liferay.portal.kernel.model.User _user;
	private HttpServletRequest _httpServletRequest;
	private HttpServletResponse _httpServletResponse;
	private UriInfo _uriInfo;

}